# Consultant

> Command line interface frontent for AI assistance.


## Getting Started

To get a local copy up and running follow these simple steps.


### Installation

Run the following command:

```sh
pip install consultant
```


## Contact

Kanelis Elias - [@email](mailto:e.kanelis@voidbuffer.com)
